--[[
	Cargolist
	
	Original author: Mick
	Reimagined and rewritten with permission: Keller

	Additional modern fixes by "Lashe Corvus"
	Special thanks to TGFT/Scion Spy for cargo regex
]]

declare ("cargolist", {})
cargolist.version = "1.2.9"
cargolist.config = "cargolist"
dofile ("data/data.lua")
dofile ("util.lua")
dofile ("ui/ui.lua")

RegisterEvent(cargolist.SectorChange, "SHIP_SPAWN_CINEMATIC_FINISHED")

function cargolist:OpenScan ()
	if PlayerInStation () then
		cargolist.ui:CreateAlertUI ("Cannot Scan inside Station")
	else
		cargolist.data.scanner = nil
		local frame = cargolist.ui:CreateUI ()
	end
end

function cargolist:OpenSettings ()
	cargolist.ui:CreateSettingsUI ()
end

function cargolist:NextDropItem ()
	local list = cargolist.data.itemList
	if cargolist.data.targetPolicy == 3 and cargolist.data.currentDrop == #list then
		cargolist:RunBackScan (nil, false)
	else
		if list and #list > 0 then
			if cargolist.data.currentDrop < #list then
				cargolist.data.currentDrop = cargolist.data.currentDrop + 1
			else
				cargolist.data.currentDrop = 1
			end
			if not cargolist.util:SetTarget () then
				cargolist.util:CleanList ()
				ProcessEvent ("CARGOLIST_RELOAD")
			else
				ProcessEvent ("CARGOLIST_SET", cargolist.data.currentDrop)
			end
		end
	end
end

function cargolist:PreviousDropItem ()
	local list = cargolist.data.itemList
	if list and #list > 0 then
		if cargolist.data.currentDrop > 1 then
			cargolist.data.currentDrop = cargolist.data.currentDrop - 1
		else
			cargolist.data.currentDrop = #list
		end
		if not cargolist.util:SetTarget () then
			cargolist.util:CleanList ()
			ProcessEvent ("CARGOLIST_RELOAD")
		else
			ProcessEvent ("CARGOLIST_SET", cargolist.data.currentDrop)
		end
	end
end

function cargolist:Help ()
	purchaseprint ("Cargolist Commands")
	purchaseprint ("-  help - Prints this list")
	purchaseprint ("-  options - Displays Control screen")
	purchaseprint ("-  scan [setName] - Performs a background scan against the current set")
	purchaseprint ("-      or against an new set defined by setName")
	purchaseprint ("- /DropScan - Shortcut command for /cargolist scan")
	purchaseprint ("- /NextDropItem - Advances to the next scanned drop item")
	purchaseprint ("- /PreviousDropItem - Reverses to the previously scanned drop item")
	purchaseprint ("- /cargolist - Open an old-style scan dialog allowing placement of the HUD list")
end

cargolist.command = {
	help = cargolist.Help,
	options = cargolist.OpenSettings,
	scan = cargolist.RunBackScan
}
function cargolist:Start (args)
	if args then
		local f = cargolist.command [args [1]:lower ()] or cargolist.Help
		f (cargolist, args)
	else
		cargolist:OpenScan ()
	end
end

function cargolist.ProcessScanSetCommand (set, args)
	if set then
		cargolist:RunBackScan ({"scan", set})
	end
end
RegisterUserCommand ("cargolist", cargolist.Start)
RegisterUserCommand ("DropScan", cargolist.RunBackScan)
RegisterUserCommand ("DropScan_All", cargolist.ProcessScanSetCommand, "All")
RegisterUserCommand ("NextDropItem", cargolist.NextDropItem)
RegisterUserCommand ("PreviousDropItem", cargolist.PreviousDropItem)